@@ -1,4 +1,3 @@
-import math
 import sys
 import warnings
 from collections import defaultdict
@@ -7,7 +6,7 @@ from typing import *
 import numpy as np
 import pandas as pd
 
-from cognite.client.data_classes import Asset, AssetList, AssetUpdate, TimeSeriesList
+from cognite.client.data_classes import Asset, AssetList, AssetUpdate, LabelFilter, TimeSeriesList
 from cognite.client.utils._concurrency import execute_tasks_concurrently
 from cognite.power.exceptions import (
     MixedPowerAssetListException,
@@ -175,9 +174,9 @@ class Terminal(PowerAsset):
             raise ValueError(f"Can't get opposite end for terminal with sequence number {seq_number}, should be 1 or 2")
         opposite_seq_number = 1 if seq_number == 2 else 2
 
-        al = self.relationship_targets(power_type="ACLineSegment", relationship_type="connectsTo")
+        al = self.relationship_targets(power_type="ACLineSegment", label="connectsTo")
         if not al:
-            pte = self.relationship_targets(power_type="PowerTransformerEnd", relationship_type="connectsTo")
+            pte = self.relationship_targets(power_type="PowerTransformerEnd", label="connectsTo")
             if not pte:
                 raise SinglePowerAssetExpected(
                     al,
@@ -353,16 +352,14 @@ class PowerTransferCorridor(PowerAsset):
     def terminals(self, sequence_number: Optional[Union[int, Iterable]] = None) -> "PowerAssetList":
         """Shortcut for finding the associated Terminals"""
         filter = self._sequence_number_filter(sequence_number)
-        return self.synchronous_machines().relationship_sources(
-            "Terminal", relationship_type="connectsTo", x_filter=filter
-        )
+        return self.synchronous_machines().relationship_sources("Terminal", label="connectsTo", x_filter=filter)
 
 
 class PowerTransformerEnd(PowerAsset, LoadDurationMixin):
     def terminals(self, sequence_number: Optional[Union[int, Iterable]] = None) -> "PowerAssetList":
         """Shortcut for finding the associated Terminals"""
         filter = self._sequence_number_filter(sequence_number)
-        return self.relationship_sources("Terminal", relationship_type="connectsTo", x_filter=filter)
+        return self.relationship_sources("Terminal", label="connectsTo", x_filter=filter)
 
     @property
     def grid_type(self) -> Optional[str]:
@@ -428,7 +425,7 @@ class SynchronousMachine(PowerAsset, LoadDurationMixin):
     def terminals(self, sequence_number: Optional[Union[int, Iterable]] = None):
         """Shortcut for finding the associated Terminals"""
         filter = self._sequence_number_filter(sequence_number)
-        return self.relationship_sources("Terminal", relationship_type="connectsTo", x_filter=filter)
+        return self.relationship_sources("Terminal", label="connectsTo", x_filter=filter)
 
     def generating_unit(self) -> GeneratingUnit:
         """Shortcut for finding the associated GeneratingUnit for a SynchronousMachine"""
@@ -447,7 +444,7 @@ class ACLineSegment(PowerAsset, LoadDurationMixin):
     def terminals(self, sequence_number: Optional[Union[int, Iterable]] = None) -> "PowerAssetList":
         """Shortcut for finding the associated Terminals"""
         filter = self._sequence_number_filter(sequence_number)
-        return self.relationship_sources("Terminal", relationship_type="connectsTo", x_filter=filter)
+        return self.relationship_sources("Terminal", label="connectsTo", x_filter=filter)
 
     def substations(self) -> "PowerAssetList":
         """Shortcut for finding the connected substations"""
@@ -587,18 +584,18 @@ class PowerAssetList(AssetList):
     def relationships(
         self,
         power_type: str = None,
-        relationship_type: str = "belongsTo",
+        label: str = "belongsTo",
         base_voltage: Optional[Iterable] = None,
         grid_type: Optional[str] = None,
         x_filter: Optional[Callable] = None,
-        _sources=None,
-        _targets=None,
+        _source_external_ids=None,
+        _target_external_ids=None,
     ) -> "PowerAssetList":
         """Internal function responsible for finding assets connected by relationships. 
 
         Args:
             power_type (str): Type of asset, e.g. PowerTransformer
-            relationship_type (str): Type of relationship, typically belongsTo or connectsTo
+            label (str): Label of the relationship, typically belongsTo or connectsTo
             base_voltage (str):
             grid_type (str):
             x_filter (Callable): Other filter to be applied to the asset, returns those for which x_filter(asset) is truthy after converting the asset to the proper type
@@ -606,17 +603,20 @@ class PowerAssetList(AssetList):
         Returns:
             PowerAssetList: list of connected assets
         """
-        if _sources and _targets:
+        if _source_external_ids and _target_external_ids:
             raise ValueError("Can not combine _sources and _targets.")
-        if not _sources and not _targets:
+        if not _source_external_ids and not _target_external_ids:
             return PowerAssetList([], cognite_client=self._cognite_client)
-        rels = self._cognite_client.relationships_playground.list(
-            sources=_sources, targets=_targets, relationship_type=relationship_type, limit=None
+        rels = self._cognite_client.relationships.list(
+            source_external_ids=_source_external_ids,
+            target_external_ids=_target_external_ids,
+            labels=LabelFilter(contains_all=[label]),
+            limit=None,
         )
-        if _sources:
-            asset_ids = [r.target["resourceId"] for r in rels]
+        if _source_external_ids:
+            asset_ids = [r.target_external_id for r in rels]
         else:
-            asset_ids = [r.source["resourceId"] for r in rels]
+            asset_ids = [r.source_external_id for r in rels]
 
         return PowerAssetList._filter_and_convert(
             self._cognite_client,
@@ -630,13 +630,13 @@ class PowerAssetList(AssetList):
     def relationship_sources(self, *args, **kwargs) -> "PowerAssetList":
         """Shortcut for finding all assets that are a source, with the current assets as targets. See PowerAssetList.relationships for list of arguments."""
         return self.relationships(
-            _sources=None, _targets=[{"resource": "Asset", "resourceId": a.external_id} for a in self], *args, **kwargs
+            _source_external_ids=None, _target_external_ids=[a.external_id for a in self], *args, **kwargs
         )
 
     def relationship_targets(self, *args, **kwargs) -> "PowerAssetList":
         """Shortcut for finding all assets that are a target, with the current assets as sources. See PowerAssetList.relationships for list of arguments."""
         return self.relationships(
-            _sources=[{"resource": "Asset", "resourceId": a.external_id} for a in self], _targets=None, *args, **kwargs
+            _source_external_ids=[a.external_id for a in self], _target_external_ids=None, *args, **kwargs
         )
 
     def power_transformer_ends(
@@ -659,10 +659,7 @@ class PowerAssetList(AssetList):
             end_number_filter = None
         if self.has_type("Terminal"):
             return self.relationship_targets(
-                "PowerTransformerEnd",
-                base_voltage=base_voltage,
-                x_filter=end_number_filter,
-                relationship_type="connectsTo",
+                "PowerTransformerEnd", base_voltage=base_voltage, x_filter=end_number_filter, label="connectsTo",
             )
         else:
             return self.relationship_sources(
@@ -767,7 +764,7 @@ class PowerAssetList(AssetList):
             return self.terminals().ac_line_segments(base_voltage=base_voltage, grid_type=grid_type)
         elif self.has_type("Terminal"):
             return self.relationship_targets(
-                "ACLineSegment", relationship_type="connectsTo", base_voltage=base_voltage, grid_type=grid_type
+                "ACLineSegment", label="connectsTo", base_voltage=base_voltage, grid_type=grid_type,
             )
         elif not self.data:
             return PowerAssetList([], cognite_client=self._cognite_client)
@@ -788,7 +785,7 @@ class PowerAssetList(AssetList):
                 sum([assets.terminals() for _type, assets in self.split_by_type().items()], []),
                 cognite_client=self._cognite_client,
             )
-        return self.relationship_sources("Terminal", relationship_type="connectsTo", x_filter=filter)
+        return self.relationship_sources("Terminal", label="connectsTo", x_filter=filter)
 
     def analogs(self):
         """Shortcut for finding the associated Analogs. Only works when applied directly to a list of Terminals."""
@@ -811,9 +808,9 @@ class PowerAssetList(AssetList):
                     f"Can't get opposite end for list with sequence number(s) {seq_numbers}, should be either all 1 or all 2"
                 )
             opposite_seq_number = 1 if list(seq_numbers)[0] == 2 else 2
-            al = self.relationship_targets(power_type="ACLineSegment", relationship_type="connectsTo")
+            al = self.relationship_targets(power_type="ACLineSegment", label="connectsTo")
             if not al:
-                pte = self.relationship_targets(power_type="PowerTransformerEnd", relationship_type="connectsTo")
+                pte = self.relationship_targets(power_type="PowerTransformerEnd", label="connectsTo")
                 return pte.opposite_ends().terminals(sequence_number=opposite_seq_number)
             return al.terminals(sequence_number=opposite_seq_number)
         else:
